==> rheolef_5.92.orig.tar.gz: rheolef-5.92/skit/ptst2/asr_exchange_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
#include "rheolef/config.h"
#ifndef _RHEOLEF_HAVE_MPI
int main() { return 0; }
#else // _RHEOLEF_HAVE_MPI

# include "rheolef/asr.h"
using namespace std;
using namespace rheolef;
int main(int argc, char**argv)
{
    environment parallel(argc, argv);
    size_t n = (argc < 2) ? 5 : atoi(argv[1]);
    asr<Float> a(n,n);
    size_t first = a.row_first_index();
    size_t last  = a.row_last_index();
    if (a.comm().rank() == 0) {
        for (size_t i = 0; i < n; i++) {
	    a.entry (i, i) = 1000+i+0.5;
        }
    }
    a.assembly();
    pcout << a.par_nrow() << " " 
	  << a.par_ncol() << " " 
	  << a.par_nnz()  << endl
          << a;
}
#endif // _RHEOLEF_HAVE_MPI

==> rheolef_5.93.orig.tar.gz: rheolef-5.93/skit/ptst2/asr_exchange_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
#include "rheolef/config.h"
#ifndef _RHEOLEF_HAVE_MPI
int main() { return 0; }
#else // _RHEOLEF_HAVE_MPI

# include "rheolef/asr.h"
using namespace std;
using namespace rheolef;
int main(int argc, char**argv)
{
    environment distributed(argc, argv);
    size_t n = (argc < 2) ? 5 : atoi(argv[1]);
    asr<Float> a(n,n);
    size_t first = a.row_first_index();
    size_t last  = a.row_last_index();
    if (a.comm().rank() == 0) {
        for (size_t i = 0; i < n; i++) {
	    a.dis_entry (i, i) = 1000+i+0.5;
        }
    }
    a.dis_entry_assembly();
    dcout << a;
}
#endif // _RHEOLEF_HAVE_MPI
